==> downloads.html?file=gigkalender_v1.2.64_009_update-65_009.zip: gigkalender/calendar/backend_showAllGigs.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  echo '<p class="Headline">'.$L_Headline01.'</p>';
  if ( !loggedIn() ) { echo $L_003; }
  else
  {
    // Inhalt hier einfügen  
      if ( AnzahlAllerGigsInDatenbank()=='0' )
      {
        echo $L_156.'<br /><br />';
      }
      else
      { 
        // Publish or Not
          if (isset($_POST['GigPublish_x'])) { changeGigPublishing ($_POST['GigID']); }
        // IsPrivate or Not
          if (isset($_POST['GigIsPrivate_x'])) { changeGigIsPrivate ($_POST['GigID']); }
        // Seiten-Navigation definieren
        // Session-Variable 'Zeitraum' definieren
          if ( isset($_POST['Zeitraum']) ) { $_SESSION["Zeitraum"] = $_POST['Zeitraum']; $_SESSION['CurrentPageShowAllGigs']=1; }
          if ( !isset($_SESSION["Zeitraum"]) ) { $_SESSION["Zeitraum"] = "future"; }
          $Zeitraum = $_SESSION["Zeitraum"];
        // Sessioin-Variable 'Anzahl' definieren
          if ( isset($_POST['Anzahl']) ) { $_SESSION["Anzahl"] = $_POST['Anzahl']; $_SESSION['CurrentPageShowAllGigs']=1; }
          if ( !isset($_SESSION["Anzahl"]) ) { $_SESSION["Anzahl"] = "25"; }
          $EintraegeProSeite = $_SESSION["Anzahl"];
        // Sessioin-Variable 'GigStatus' definieren
          if ( isset($_POST['AuswahlGigStatus']) ) { $_SESSION["AuswahlGigStatus"] = $_POST['AuswahlGigStatus']; $_SESSION['CurrentPageShowAllGigs']=1;}
          if ( !isset($_SESSION["AuswahlGigStatus"]) ) { $_SESSION["AuswahlGigStatus"] = "all"; }
          $AuswahlGigStatus = $_SESSION["AuswahlGigStatus"];
        // Parameter für Navigation definieren
          $AnzahlGigsImZeitraum = AnzahlGigsImZeitraum($Zeitraum, $AuswahlGigStatus);
          if ( $EintraegeProSeite!='all' ) { $AnzahlSeiten = ceil($AnzahlGigsImZeitraum/$EintraegeProSeite); }
            else { $AnzahlSeiten = '0'; }
          if (isset($_REQUEST['page'])) { $_SESSION['CurrentPageShowAllGigs'] = $_REQUEST['page']; }
          if ( !isset($_SESSION['CurrentPageShowAllGigs']) ) { $_SESSION['CurrentPageShowAllGigs'] = "1"; }
          $aktuelleSeite = $_SESSION['CurrentPageShowAllGigs'];
          $obersterGig  = $EintraegeProSeite*($aktuelleSeite-1);
        // Ansichts-Parameter
        echo '<div id="Box_ParameterShowGigs">
                <form method="post" action="index.php?submenue=calendar&amp;inhalt=backend_showAllGigs" accept-charset="UTF-8">
                  <fieldset>
                    <input type="hidden" name="thread[threadid]" value="$thread[threadid]" />                 
                    <select name="Anzahl" onchange="this.form.submit()">
                      <option value="all"'; if ($EintraegeProSeite=="all") echo ' selected="selected"'; echo'>'.$L_ShowAllGigs.'</option>';
                    for ($i=1; $i<=100; $i++)
                    {
                      echo '<option value="'.$i.'"'; if ($EintraegeProSeite==$i) echo ' selected="selected"'; echo'>'.$i.'</option>';
                    }

                  echo '</select>
                  </fieldset>
                </form>
                <form method="post" action="index.php?submenue=calendar&amp;inhalt=backend_showAllGigs" accept-charset="UTF-8">
                  <fieldset>
                    <input type="hidden" name="thread[threadid]" value="$thread[threadid]" />
                    <select name="Zeitraum" onchange="this.form.submit()">
                      <option value="all"'; if ($Zeitraum=="all") echo ' selected="selected"'; echo'>'.$L_ShowAllGigs.'</option>
                      <option value="future"'; if ($Zeitraum=="future") echo ' selected="selected"'; echo'>'.$L_ShowFutureGigs.'</option>
                      <option value="past"'; if ($Zeitraum=="past") echo ' selected="selected"'; echo'>'.$L_ShowPastGigs.'</option>
                    </select>
                  </fieldset>
                </form>        
                <form method="post" action="index.php?submenue=calendar&amp;inhalt=backend_showAllGigs" accept-charset="UTF-8">
                  <fieldset>
                    <input type="hidden" name="thread[threadid]" value="$thread[threadid]" />
                    <select name="AuswahlGigStatus" onchange="this.form.submit()">
                      <option value="all"'; if ($AuswahlGigStatus=="all") echo ' selected="selected"'; echo'>'.$L_ShowAllGigs.'</option>
                      <option value="Gig"'; if ($AuswahlGigStatus=="Gig") echo ' selected="selected"'; echo'>'.$L_GigStatusGig.'</option>
                      <option value="Option"'; if ($AuswahlGigStatus=="Option") echo ' selected="selected"'; echo'>'.$L_GigStatusOption.'</option>
                      <option value="Rehearsal"'; if ($AuswahlGigStatus=="Rehearsal") echo ' selected="selected"'; echo'>'.$L_GigStatusRehearsal.'</option>
                      <option value="Blocked"'; if ($AuswahlGigStatus=="Blocked") echo ' selected="selected"'; echo'>'.$L_GigStatusBlocked.'</option>
                    </select>
                  </fieldset>
                </form>';
        // Attribute-Editor
      echo '<form method="post" action="index.php?submenue=calendar&amp;inhalt=backend_editAttributes&amp;referer=backend_showAllGigs&amp;job=0&amp;id=0&amp;timestamp=0" accept-charset="UTF-8">
               <fieldset>
                 <input style="font-size:0.9em;" type="submit" value="'.$L_Button28.'" class="SmallButton" />
                 <input type="hidden" name="Selector" value="backend_showAllGigs" />
                  <input type="hidden" name="referer" value="backend_showAllGigs" />
               </fieldset>
             </form>';
        echo GigNavigation();
        
        echo '</div>';
      // Datensatz-Ausgabe festlegen
        $TimestampVonHeute = TimestampAusDatum(date("d"), date("m"), date("y")); 
        $sql = "SELECT * FROM ".$prefix."gigs";
        if ( $Zeitraum!='all' OR $AuswahlGigStatus!='all' ) { $sql = $sql.' WHERE ';}
        if ( $Zeitraum =="future" ) 
          { $sql = $sql."GigDate>=".$TimestampVonHeute; }
        if ( $Zeitraum =="past" ) 
          { $sql = $sql."GigDate<".$TimestampVonHeute; }          
        if ( $Zeitraum!='all' && $AuswahlGigStatus!='all' ) { $sql = $sql.' AND ';}
        if ( $AuswahlGigStatus!='all' ) { $sql = $sql." GigStatus='".$AuswahlGigStatus."'"; }
        if ( $Zeitraum =="future" ) 
          { $sql = $sql." order by GigDate, GigBeginning"; }
        if ( $Zeitraum =="past" ) 
          { $sql = $sql." order by GigDate DESC, GigBeginning DESC"; }
        if ( $Zeitraum =="all" ) 
          { $sql = $sql." order by GigDate"; }
        $sql = $sql." LIMIT ".$obersterGig.", "; 
        if ( $EintraegeProSeite=='all') { $sql = $sql.$AnzahlGigsImZeitraum; }
        else { $sql = $sql.$EintraegeProSeite; }
        $resultat = mysql_db_query($db_name, $sql);

      // Ausgabe der Gig-Übersicht
        if ( $AnzahlGigsImZeitraum!=0 ) // Einträge vorhanden
        {   
          $UserBackendCalenderListCols = getCurrentUserVar ('UserBackendCalenderListCols');
          if ( $UserBackendCalenderListCols!="" ) $Attribute = explode (', ',$UserBackendCalenderListCols);
            else $Attribute = array();
          echo '<table id="WideTable" summary="Tabelle_Zeige-Gigs">';
          // Spalten definieren
            echo '<colgroup>';
            if ( IsUserAdmin() ) { echo '<col class="SpalteIcon" />'; }
            echo '<col class="SpalteIcon" />';
            echo '<col class="GigStatus" />';
            for ($i=0; $i<(count($Attribute)); $i++)
              echo '<col id="'.$Attribute[$i].'" />';
            echo '</colgroup>';
          // Spaltenköpfe definieren
            echo '<tr>';
            if ( IsUserAdmin() ) { echo'<th class="Screen">&nbsp;</th>'; }
            echo '<th class="Screen">&nbsp;</th>
                  <th>'.$L_GigDate.'</th>';
            echo '<th class="GigPrint">'.$L_GigStatus.'</th>';
            // Definierte Spalten
              for ( $x = 0; $x < count ( $Attribute ); $x++ )
              {
                if ( $x!=count($Attribute)-1 ) echo '<th>';
                  else echo '<th class="TabellenSpalte_Rechts">';
                switch ( $Attribute[$x] )
                {
                  case "GigIsPrivate": echo '<img src="images/private.gif" alt="'.$L_Private.'" title="'.$L_Private.'" />'; break;
                  case "GigPublish": echo '<img src="images/frontend.gif" alt="'.$L_Publish.'" title="'.$L_Publish.'" />'; break;
                  case "GigBeginning": echo '<img src="images/time.gif" alt="" title="" />'; break;
                  default: echo ''.${'L_'.$Attribute[$x]}; break;
                }
                echo '</th>';
              }
            //
            echo '</tr>';
          //
          while ($row = mysql_fetch_array($resultat))
          {
            extract($row);
            echo '<tr>';
            if ( IsUserAdmin() )
            {
              echo '<td class="Screen '.$GigStatus.'">
                      <a href="index.php?submenue=calendar&amp;inhalt=backend_delGig&amp;id='.$GigID.'">
                        <img src="images/delete.gif" alt="'.$L_009.'" title="'.$L_009.'" /></a>
                    </td>
                    <td class="Screen '.$GigStatus.'">
                      <a href="index.php?submenue=calendar&amp;inhalt=backend_addGig&amp;job=edit&amp;id='.$GigID.'">
                        <img src="images/edit.gif" alt="'.$L_010.'" title="'.$L_010.'" /></a>
                    </td>';
            }
            else
            {
              echo '<td class="Screen '.$GigStatus.'">
                      <a href="index.php?submenue=calendar&amp;inhalt=backend_showGig&amp;id='.$GigID.'">
                        <img src="images/show.png" alt="'.$L_153.'" title="'.$L_153.'" /></a>
                    </td>';
            }
            // GigDate
            echo '<td class="'.$GigStatus.'">'.date($SetupBackendDateFormat, $GigDate).'</td>';
            // ColGigStatusPrint
            echo '<td class="GigPrint">'.$GigStatus.'</td>';
            // Definierte Spalten
            for ( $x = 0; $x < count ( $Attribute ); $x++ )
            {
              if ( $x!=count($Attribute)-1 ) echo '<td class="'.$GigStatus.'">';
                else echo '<td class="'.$GigStatus.' TabellenSpalte_Rechts">';
              include ('calendar/includes/showAllGigs/'.$Attribute[$x].'.php');
              echo '</td>';
            }
            //
            echo '</tr>';
          }
          echo '</table>';
          include("calendar/backend_legende.php");
        }
        else { echo '<br />'.$L_154."<br /><br />";}
      }
      if ( IsUserAdmin() ) 
      {
        echo '<a href="index.php?submenue=calendar&amp;inhalt=backend_addGig&amp;job=add">
                <img src="images/add.gif" alt="'.$L_002.'" title="'.$L_002.'" /></a>';
      }
      include ('includes/toolbar.php');
    // Inhalt zuende      
  }
?>

==> downloads.html?file=gigkalender_v1.2.72_002_update-75_017.zip: gigkalender/calendar/backend_showAllGigs.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  echo '<p class="Headline">'.$L_Headline01.'</p>';
  if ( !loggedIn() ) { echo $L_003; }
  else
  {
    // Inhalt hier einfügen  
      if ( AnzahlAllerGigsInDatenbank()=='0' )
      {
        echo $L_156.'<br /><br />';
      }
      else
      { 
        // Publish or Not
          if (isset($_POST['GigPublish_x'])) { changeGigPublishing ($_POST['GigID']); }
        // IsPrivate or Not
          if (isset($_POST['GigIsPrivate_x'])) { changeGigIsPrivate ($_POST['GigID']); }
        // Seiten-Navigation definieren
        // Session-Variable 'Zeitraum' definieren
          if ( isset($_POST['Zeitraum']) ) { $_SESSION["Zeitraum"] = $_POST['Zeitraum']; $_SESSION['CurrentPageShowAllGigs']=1; }
          if ( !isset($_SESSION["Zeitraum"]) ) { $_SESSION["Zeitraum"] = "future"; }
          $Zeitraum = $_SESSION["Zeitraum"];
        // Sessioin-Variable 'Anzahl' definieren
          if ( isset($_POST['Anzahl']) ) { $_SESSION["Anzahl"] = $_POST['Anzahl']; $_SESSION['CurrentPageShowAllGigs']=1; }
          if ( !isset($_SESSION["Anzahl"]) ) { $_SESSION["Anzahl"] = "25"; }
          $EintraegeProSeite = $_SESSION["Anzahl"];
        // Sessioin-Variable 'GigStatus' definieren
          if ( isset($_POST['AuswahlGigStatus']) ) { $_SESSION["AuswahlGigStatus"] = $_POST['AuswahlGigStatus']; $_SESSION['CurrentPageShowAllGigs']=1;}
          if ( !isset($_SESSION["AuswahlGigStatus"]) ) { $_SESSION["AuswahlGigStatus"] = "all"; }
          $AuswahlGigStatus = $_SESSION["AuswahlGigStatus"];
        // Parameter für Navigation definieren
          $AnzahlGigsImZeitraum = AnzahlGigsImZeitraum($Zeitraum, $AuswahlGigStatus);
          if ( $EintraegeProSeite!='all' ) { $AnzahlSeiten = ceil($AnzahlGigsImZeitraum/$EintraegeProSeite); }
            else { $AnzahlSeiten = '0'; }
          if (isset($_REQUEST['page'])) { $_SESSION['CurrentPageShowAllGigs'] = $_REQUEST['page']; }
          if ( !isset($_SESSION['CurrentPageShowAllGigs']) ) { $_SESSION['CurrentPageShowAllGigs'] = "1"; }
          $aktuelleSeite = $_SESSION['CurrentPageShowAllGigs'];
          $obersterGig  = $EintraegeProSeite*($aktuelleSeite-1);
        // Ansichts-Parameter
        echo '<div id="Box_ParameterShowGigs">
                <form method="post" action="index.php?submenue=calendar&amp;inhalt=backend_showAllGigs" accept-charset="UTF-8">
                  <fieldset>
                    <input type="hidden" name="thread[threadid]" value="$thread[threadid]" />                 
                    <select name="Anzahl" onchange="this.form.submit()">
                      <option value="all"'; if ($EintraegeProSeite=="all") echo ' selected="selected"'; echo'>'.$L_ShowAllGigs.'</option>';
                    for ($i=1; $i<=100; $i++)
                    {
                      echo '<option value="'.$i.'"'; if ($EintraegeProSeite==$i) echo ' selected="selected"'; echo'>'.$i.'</option>';
                    }

                  echo '</select>
                  </fieldset>
                </form>
                <form method="post" action="index.php?submenue=calendar&amp;inhalt=backend_showAllGigs" accept-charset="UTF-8">
                  <fieldset>
                    <input type="hidden" name="thread[threadid]" value="$thread[threadid]" />
                    <select name="Zeitraum" onchange="this.form.submit()">
                      <option value="all"'; if ($Zeitraum=="all") echo ' selected="selected"'; echo'>'.$L_ShowAllGigs.'</option>
                      <option value="future"'; if ($Zeitraum=="future") echo ' selected="selected"'; echo'>'.$L_ShowFutureGigs.'</option>
                      <option value="past"'; if ($Zeitraum=="past") echo ' selected="selected"'; echo'>'.$L_ShowPastGigs.'</option>
                    </select>
                  </fieldset>
                </form>        
                <form method="post" action="index.php?submenue=calendar&amp;inhalt=backend_showAllGigs" accept-charset="UTF-8">
                  <fieldset>
                    <input type="hidden" name="thread[threadid]" value="$thread[threadid]" />
                    <select name="AuswahlGigStatus" onchange="this.form.submit()">
                      <option value="all"'; if ($AuswahlGigStatus=="all") echo ' selected="selected"'; echo'>'.$L_ShowAllGigs.'</option>
                      <option value="Gig"'; if ($AuswahlGigStatus=="Gig") echo ' selected="selected"'; echo'>'.$L_GigStatusGig.'</option>
                      <option value="Option"'; if ($AuswahlGigStatus=="Option") echo ' selected="selected"'; echo'>'.$L_GigStatusOption.'</option>
                      <option value="Rehearsal"'; if ($AuswahlGigStatus=="Rehearsal") echo ' selected="selected"'; echo'>'.$L_GigStatusRehearsal.'</option>
                      <option value="Blocked"'; if ($AuswahlGigStatus=="Blocked") echo ' selected="selected"'; echo'>'.$L_GigStatusBlocked.'</option>
                    </select>
                  </fieldset>
                </form>';
        // Attribute-Editor
      echo '<form method="post" action="index.php?submenue=calendar&amp;inhalt=backend_editAttributes&amp;referer=backend_showAllGigs&amp;job=0&amp;id=0&amp;timestamp=0" accept-charset="UTF-8">
               <fieldset>
                 <input style="font-size:0.9em;" type="submit" value="'.$L_Button28.'" class="SmallButton" />
                 <input type="hidden" name="Selector" value="backend_showAllGigs" />
                  <input type="hidden" name="referer" value="backend_showAllGigs" />
               </fieldset>
             </form>';
        echo GigNavigation();
        
        echo '</div>';
      // Datensatz-Ausgabe festlegen
        $TimestampVonHeute = TimestampAusDatum(date("d"), date("m"), date("y")); 
        $sql = "SELECT * FROM ".$prefix."gigs";
        if ( $Zeitraum!='all' OR $AuswahlGigStatus!='all' ) { $sql = $sql.' WHERE ';}
        if ( $Zeitraum =="future" ) 
          { $sql = $sql."GigDate>=".$TimestampVonHeute; }
        if ( $Zeitraum =="past" ) 
          { $sql = $sql."GigDate<".$TimestampVonHeute; }          
        if ( $Zeitraum!='all' && $AuswahlGigStatus!='all' ) { $sql = $sql.' AND ';}
        if ( $AuswahlGigStatus!='all' ) { $sql = $sql." GigStatus='".$AuswahlGigStatus."'"; }
        if ( $Zeitraum =="future" ) 
          { $sql = $sql." order by GigDate, GigBeginning"; }
        if ( $Zeitraum =="past" ) 
          { $sql = $sql." order by GigDate DESC, GigBeginning DESC"; }
        if ( $Zeitraum =="all" ) 
          { $sql = $sql." order by GigDate"; }
        $sql = $sql." LIMIT ".$obersterGig.", "; 
        if ( $EintraegeProSeite=='all') { $sql = $sql.$AnzahlGigsImZeitraum; }
        else { $sql = $sql.$EintraegeProSeite; }
        $resultat = mysqli_query($db, $sql);

      // Ausgabe der Gig-Übersicht
        if ( $AnzahlGigsImZeitraum!=0 ) // Einträge vorhanden
        {   
          $UserBackendCalenderListCols = getCurrentUserVar ('UserBackendCalenderListCols');
          if ( $UserBackendCalenderListCols!="" ) $Attribute = explode (', ',$UserBackendCalenderListCols);
            else $Attribute = array();
          echo '<table id="WideTable" summary="Tabelle_Zeige-Gigs">';
          // Spalten definieren
            echo '<colgroup>';
            if ( IsUserAdmin() ) { echo '<col class="SpalteIcon" />'; }
            echo '<col class="SpalteIcon" />';
            echo '<col class="GigStatus" />';
            for ($i=0; $i<(count($Attribute)); $i++)
              echo '<col id="'.$Attribute[$i].'" />';
            echo '</colgroup>';
          // Spaltenköpfe definieren
            echo '<tr>';
            if ( IsUserAdmin() ) { echo'<th class="Screen">&nbsp;</th>'; }
            echo '<th class="Screen">&nbsp;</th>
                  <th>'.$L_GigDate.'</th>';
            echo '<th class="GigPrint">'.$L_GigStatus.'</th>';
            // Definierte Spalten
              for ( $x = 0; $x < count ( $Attribute ); $x++ )
              {
                if ( $x!=count($Attribute)-1 ) echo '<th>';
                  else echo '<th class="TabellenSpalte_Rechts">';
                switch ( $Attribute[$x] )
                {
                  case "GigIsPrivate": echo '<img src="images/private.gif" alt="'.$L_Private.'" title="'.$L_Private.'" />'; break;
                  case "GigPublish": echo '<img src="images/frontend.gif" alt="'.$L_Publish.'" title="'.$L_Publish.'" />'; break;
                  case "GigBeginning": echo '<img src="images/time.gif" alt="" title="" />'; break;
                  default: echo ''.${'L_'.$Attribute[$x]}; break;
                }
                echo '</th>';
              }
            //
            echo '</tr>';
          //
          while ($row = mysqli_fetch_array($resultat))
          {
            extract($row);
            echo '<tr>';
            if ( IsUserAdmin() )
            {
              echo '<td class="Screen '.$GigStatus.'">
                      <a href="index.php?submenue=calendar&amp;inhalt=backend_delGig&amp;id='.$GigID.'">
                        <img src="images/delete.gif" alt="'.$L_009.'" title="'.$L_009.'" /></a>
                    </td>
                    <td class="Screen '.$GigStatus.'">
                      <a href="index.php?submenue=calendar&amp;inhalt=backend_addGig&amp;job=edit&amp;id='.$GigID.'">
                        <img src="images/edit.gif" alt="'.$L_010.'" title="'.$L_010.'" /></a>
                    </td>';
            }
            else
            {
              echo '<td class="Screen '.$GigStatus.'">
                      <a href="index.php?submenue=calendar&amp;inhalt=backend_showGig&amp;id='.$GigID.'">
                        <img src="images/show.png" alt="'.$L_153.'" title="'.$L_153.'" /></a>
                    </td>';
            }
            // GigDate
            echo '<td class="'.$GigStatus.'">'.date($SetupBackendDateFormat, $GigDate).'</td>';
            // ColGigStatusPrint
            echo '<td class="GigPrint">'.$GigStatus.'</td>';
            // Definierte Spalten
            for ( $x = 0; $x < count ( $Attribute ); $x++ )
            {
              if ( $x!=count($Attribute)-1 ) echo '<td class="'.$GigStatus.'">';
                else echo '<td class="'.$GigStatus.' TabellenSpalte_Rechts">';
              include ('calendar/includes/showAllGigs/'.$Attribute[$x].'.php');
              echo '</td>';
            }
            //
            echo '</tr>';
          }
          echo '</table>';
          include("calendar/backend_legende.php");
        }
        else { echo '<br />'.$L_154."<br /><br />";}
      }
      if ( IsUserAdmin() ) 
      {
        echo '<a href="index.php?submenue=calendar&amp;inhalt=backend_addGig&amp;job=add">
                <img src="images/add.gif" alt="'.$L_002.'" title="'.$L_002.'" /></a>';
      }
      include ('includes/toolbar.php');
    // Inhalt zuende      
  }
?>
